@@ -301,7 +301,7 @@ class YaappConfig:
                         'config': plugin_config
                     }
                     
-                    print(f"✅ Loaded plugin: {section_name}")
+                    # Plugin loaded - will be instantiated later
                     
                 except Exception as e:
                     # Log warning but continue with other plugins
@@ -339,12 +339,17 @@ class YaappConfig:
                             plugin_instance.yaapp = app_instance
                             
                             # Replace the class with the instance in the registry
-                            app_instance._registry[section_name] = (plugin_instance, app_instance._registry[section_name][1])
+                            exposer = app_instance._registry[section_name][1]
+                            app_instance._registry[section_name] = (plugin_instance, exposer)
                             
-                            print(f"🔗 Plugin ready: {section_name} (instantiated with config)")
+                            # Call the exposer's expose method on the new instance to trigger expose_to_registry
+                            if hasattr(exposer, 'expose'):
+                                exposer.expose(plugin_instance, section_name, custom=True)
+                            
+                            print(f"✅ {section_name} ready")
                         else:
                             # Already an instance
-                            print(f"🔗 Plugin ready: {section_name} (already instantiated)")
+                            print(f"✅ {section_name} ready")
                     else:
                         print(f"Warning: Plugin '{section_name}' not found in registry")
                 except Exception as e:
