@@ -26,6 +26,7 @@ class YaappCore:
     def __init__(self):
         """Initialize the core yaapp functionality."""
         self._config: Optional[YaappConfig] = None
+        self._config_file_override: Optional[str] = None
 
         # Context tree for navigation (replaces fragile string manipulation)
         self._context_tree = ContextTree()
@@ -38,6 +39,17 @@ class YaappCore:
 
         # Registry stores (object, exposer) pairs for proper execution
         self._registry: Dict[str, Tuple[Any, BaseExposer]] = {}
+    
+    def set_config_file_override(self, config_file: Optional[str]) -> None:
+        """Set a config file that overrides the standard search paths.
+        
+        Args:
+            config_file: Path to config file that should take precedence over
+                        current directory and other standard locations
+        """
+        self._config_file_override = config_file
+        # Clear cached config so it gets reloaded with the override
+        self._config = None
 
     def expose(
         self,
@@ -257,20 +269,32 @@ class YaappCore:
         config_file = None
         secrets_file = None
 
-        # Search paths: current directory, script directory
-        search_paths = self._get_config_search_paths()
+        # Check for config file override first (highest priority)
+        if self._config_file_override:
+            config_path = Path(self._config_file_override)
+            if config_path.exists():
+                config_file = str(config_path)
+                print(f"Using config override: {config_file}")
+            else:
+                print(f"Warning: Config override file not found: {self._config_file_override}")
+        
+        # If no override or override file doesn't exist, use standard search paths
+        if not config_file:
+            # Search paths: current directory, script directory
+            search_paths = self._get_config_search_paths()
 
-        # Look for main config files in all search paths
-        for search_path in search_paths:
-            for config_name in ["yaapp.yaml", "yaapp.yml", "yaapp.json"]:
-                config_path = search_path / config_name
-                if config_path.exists():
-                    config_file = str(config_path)
+            # Look for main config files in all search paths
+            for search_path in search_paths:
+                for config_name in ["yaapp.yaml", "yaapp.yml", "yaapp.json"]:
+                    config_path = search_path / config_name
+                    if config_path.exists():
+                        config_file = str(config_path)
+                        break
+                if config_file:
                     break
-            if config_file:
-                break
 
         # Look for secrets files in all search paths
+        search_paths = self._get_config_search_paths()
         for search_path in search_paths:
             for secrets_name in [
                 "yaapp.secrets.yaml",
