@@ -12,11 +12,11 @@ import uuid
 from datetime import datetime, timedelta
 from typing import Dict, List, Optional, Any
 
-from yaapp import yaapp
+from yaapp import expose
 from yaapp.result import Result, Ok
 
 
-@yaapp.expose('auth')
+@expose(name='auth')
 class AuthPlugin:
     """
     Authentication and Authorization plugin for yaapp.
