@@ -23,7 +23,7 @@ from typing import Any, Dict, List, Optional
 
 logger = logging.getLogger(__name__)
 
-from yaapp import yaapp
+from yaapp import expose
 
 
 @dataclass
@@ -134,7 +134,7 @@ class PtyReader:
         logger.info("PtyReader: Stopped")
 
 
-@yaapp.expose("remote")
+@expose(name="remote")
 class RemoteProcess:
     """Manages a subprocess with PTY for proper interactive behavior"""
 
