@@ -15,7 +15,7 @@ from pathlib import Path
 from typing import (Any, Dict, List, Optional, Protocol, Tuple, Union,
                     runtime_checkable)
 
-from yaapp import yaapp
+from yaapp import expose
 
 
 @runtime_checkable
@@ -459,7 +459,7 @@ class SQLiteStorage:
             except sqlite3.Error:
                 return 0
 
-@yaapp.expose('storage')
+@expose(name='storage')
 class Storage:
     """Storage manager with single backend configured through yaapp config."""
     
